@@ -1,14 +1,14 @@
 class Compressor:
-    name = ''
+    name: str
 
-    @staticmethod
     def compress(
-        data,
-    ):
+        self,
+        data: bytes,
+    ) -> bytes:
         raise NotImplementedError()
 
-    @staticmethod
     def decompress(
-        data,
-    ):
+        self,
+        data: bytes,
+    ) -> bytes:
         raise NotImplementedError()
